@@ -1,5 +1,5 @@
 /* m17n-core.h -- header file for the CORE API of the m17n library.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 #ifndef _M17N_CORE_H_
 #define _M17N_CORE_H_
@@ -46,9 +46,9 @@ M17N_BEGIN_HEADER
 #if !defined (FOR_DOXYGEN) || defined (DOXYGEN_INTERNAL_MODULE)
 
 #define M17NLIB_MAJOR_VERSION 1
-#define M17NLIB_MINOR_VERSION 5
-#define M17NLIB_PATCH_LEVEL 5
-#define M17NLIB_VERSION_NAME "1.5.5"
+#define M17NLIB_MINOR_VERSION 8
+#define M17NLIB_PATCH_LEVEL 1
+#define M17NLIB_VERSION_NAME "1.8.1"
 
 extern void m17n_init_core (void);
 #define M17N_INIT() m17n_init_core ()
@@ -119,6 +119,7 @@ extern enum M17NStatus m17n_status (void);
 
 typedef struct
 {
+  /*** Hidden from applications.  */
   void *filler[2];
 } M17NObjectHead;
 
@@ -420,11 +421,17 @@ typedef struct MText MText;
 
 enum MTextFormat
   {
+    /*** US-ASCII encoding */
     MTEXT_FORMAT_US_ASCII,
+    /*** UTF-8 encoding */
     MTEXT_FORMAT_UTF_8,
+    /*** UTF-16LE encoding  */
     MTEXT_FORMAT_UTF_16LE,
+    /*** UTF-16BE encoding  */
     MTEXT_FORMAT_UTF_16BE,
+    /*** UTF-32LE encoding  */
     MTEXT_FORMAT_UTF_32LE,
+    /*** UTF-32BE encoding  */
     MTEXT_FORMAT_UTF_32BE,
     MTEXT_FORMAT_MAX
   };
@@ -582,6 +589,7 @@ extern int mtext_titlecase (MText *mt);
 
 extern int mtext_uppercase (MText *mt);
 
+/*** @ingroup m17nMtext */
 /***en
     @brief Enumeration for specifying a set of line breaking option.
 
@@ -713,7 +721,7 @@ typedef MPlist *(*MTextPropSerializeFunc) (void *val);
     @brief ǥꥢ饤ؿη.
 
     ǥꥢ饤ؿηǤ롣 륷ܥΥץѥƥΥ @c
-    #Msymbol_prop_deserializer ǤȤ ͤϤηǤʤƤϤʤʤ
+    #Mtext_prop_deserializer ǤȤ ͤϤηǤʤƤϤʤʤ
 
     @seealso
     Mtext_prop_deserialize (), Mtext_prop_deserializer
